package com.ruoyi.project.sems.mapper;

import java.util.List;
import com.ruoyi.framework.aspectj.lang.annotation.DataScope;
import com.ruoyi.project.sems.domain.TSpecFile;

/**
 * 特种设备文件Mapper接口
 * 
 * @author ruoyi
 * @date 2021-08-02
 */
public interface TSpecFileMapper 
{
    /**
     * 查询特种设备文件
     * 
     * @param id 特种设备文件ID
     * @return 特种设备文件
     */
    public TSpecFile selectTSpecFileById(Long id);

    /**
     * 查询特种设备文件列表
     * 
     * @param tSpecFile 特种设备文件
     * @return 特种设备文件集合
     */
    @DataScope(deptAlias = "d")
    public List<TSpecFile> selectTSpecFileList(TSpecFile tSpecFile);

    /**
     * 新增特种设备文件
     * 
     * @param tSpecFile 特种设备文件
     * @return 结果
     */
    public int insertTSpecFile(TSpecFile tSpecFile);

    /**
     * 修改特种设备文件
     * 
     * @param tSpecFile 特种设备文件
     * @return 结果
     */
    public int updateTSpecFile(TSpecFile tSpecFile);

    /**
     * 删除特种设备文件
     * 
     * @param id 特种设备文件ID
     * @return 结果
     */
    public int deleteTSpecFileById(Long id);

    /**
     * 批量删除特种设备文件
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteTSpecFileByIds(Long[] ids);
}
